﻿using System;
using GrapeCity.Documents.Drawing;
using GrapeCity.Documents.Text;
using GrapeCity.Documents.Imaging;
using System.Drawing;
using System.IO;

namespace prj_GcImaging_RoundEdgeImage
{
    class Program
    {
        
        static void Main(string[] args)
        {
            Program program = new Program();
            Console.WriteLine("Creating a round-edged image");
            var fname = "RoundClip.png";
            var bmp =program.GenerateImage();

            bmp.SaveAsPng(fname);

            Console.WriteLine("Press any key to exit...");
            Console.ReadKey();
        }
        public GcBitmap GenerateImage(int pixelWidth = 1024, int pixelHeight = 1024, bool opaque = true, float dpiX = 96, float dpiY = 96)
        {
            //we use solid color as background here 
            //as some image formats may not support transparent background
            Color backColor = Color.AntiqueWhite;
            Color foreColor = Color.Beige;
            const int bottom = 144, pad = 36;
            int minSize = Math.Min(pixelWidth, pixelHeight) / 6, maxSize = (int)(Math.Min(pixelWidth, pixelHeight) / 1.5);
            
            // Randomize some parameters of the sample:
            var rnd = new Random();
            // It is advisable to dispose bitmaps which are no longer needed,
            // so we are 'using' all bitmaps except the one returned:

            using (var bmpSrc = new GcBitmap(Path.Combine("Resources", "woman-brick-wall.jpg")))
            {
                // Make sure source and target opacity match:
                bmpSrc.Opaque = opaque;
                
                // Coordinates and size of the clipping in the source image:
                const int x = 50, y = 0, w = 900, h = 900;
                
                // Create a clipping region excluding all outside of the specified circle:
                var rgn = new Region(new RectangularFigure(0, 0, bmpSrc.PixelWidth, bmpSrc.PixelHeight));
                var ellipse = new EllipticFigure(x, y, w, h);
                rgn.CombineWithRegion(new Region(ellipse), RegionCombineMode.Exclude, false);
                
                // To clip using a Region, we need to use the BitmapRenderer:
                var renderer = bmpSrc.Renderer;
                renderer.ClipRegion = rgn;
                renderer.Clear(Color.Transparent);

                var size = rnd.Next(minSize, maxSize);
                using (var bmpRound = bmpSrc.Clip(new Rectangle(x, y, w, h)))
                using (var bmpSmall = bmpRound.Resize(size, size))
                {
                    var bmp = new GcBitmap(pixelWidth, pixelHeight, opaque, dpiX, dpiY);
                    bmp.Clear(Color.Transparent);
                    bmp.BitBlt(bmpSmall,
                        rnd.Next(pad, pixelWidth - pad - bmpSmall.PixelWidth),
                        rnd.Next(pad, pixelHeight - pad - bottom - bmpSmall.PixelHeight));
                    return bmp;
                }
            }
        }
     }
}
